OC.L10N.register(
    "core",
    {
    "Please select a file." : "Válasszon egy fájlt.",
    "File is too big" : "A fájl túl nagy",
    "The selected file is not an image." : "A kiválasztott fájl nem kép.",
    "The selected file cannot be read." : "A kiválasztott fájl nem olvasható.",
    "The file was uploaded" : "A fájl feltöltve",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "A feltöltött fájl meghaladja a php.ini-ben szereplő upload_max_filesize direktívában megadott méretet",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "A feltöltött fájl meghaladja a HTML űrlapon megadott MAX_FILE_SIZE direktívában meghatározott méretet.",
    "The file was only partially uploaded" : "A fájl csak részben került feltöltésre",
    "No file was uploaded" : "Egyetlen fájl sem töltődött fel",
    "Missing a temporary folder" : "Hiányzik egy ideiglenes mappa",
    "Could not write file to disk" : "Nem lehet a fájlt lemezre írni",
    "A PHP extension stopped the file upload" : "Egy PHP kiterjesztés megállította a fájl feltöltését",
    "Invalid file provided" : "Érvénytelen fájl van megadva",
    "No image or file provided" : "Nincs kép vagy fájl megadva",
    "Unknown filetype" : "Ismeretlen fájltípus",
    "An error occurred. Please contact your admin." : "Hiba történt. Lépjen kapcsolatba a rendszergazdával.",
    "Invalid image" : "Érvénytelen kép",
    "No temporary profile picture available, try again" : "Nem érhető el átmeneti profilkép, próbálja újra",
    "No crop data provided" : "Nincs levágási adat megadva",
    "No valid crop data provided" : "Nincs érvényes levágási adat megadva",
    "Crop is not square" : "A levágás nem négyzet alakú",
    "State token does not match" : "Az állapottoken nem megfelelő",
    "Invalid app password" : "Érvénytelen alkalmazásjelszó",
    "Could not complete login" : "A bejelentkezés nem fejezhető be",
    "Your login token is invalid or has expired" : "A bejelentkezési token érvénytelen vagy lejárt",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "A Nextcloud e közösségi kiadása nem támogatott, és a leküldéses értesítések korlátozottak.",
    "Login" : "Bejelentkezés",
    "Password reset is disabled" : "Jelszó visszaállítás letiltva",
    "Could not reset password because the token is expired" : "A jelszót nem lehet visszaállítani, mert a token lejárt",
    "Could not reset password because the token is invalid" : "A jelszót nem lehet visszaállítani, mert a token érvénytelen",
    "%s password reset" : "%s jelszó visszaállítás",
    "Password reset" : "Jelszó visszaállítás",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Kattintson a lenti gombra a jelszava visszaállításához. Ha ezt nem Ön kérte, akkor hagyja figyelmen kívül ezt a levelet.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Kattintson a lenti hivatkozásra a jelszava visszaállításához. Ha ezt nem Ön kérte, akkor hagyja figyelmen kívül ezt a levelet.",
    "Reset your password" : "Jelszó visszaállítása",
    "Nextcloud Server" : "Nextcloud kiszolgáló",
    "Some of your link shares have been removed" : "Néhány megosztási hivatkozása eltávolításra került",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Egy biztonsági hiba miatt el kellett távolítsunk néhány megosztási hivatkozását. További információkért lásd a lenti hivatkozást.",
    "The user limit of this instance is reached." : "Elérte ennek a példánynak a felhasználói korlátját.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Adja meg előfizetésének kulcsát a felhasználói korlát növeléséhez. További információ a Nextcloud Enterprise-ról a weboldalunkon található.",
    "Preparing update" : "Felkészülés a frissítésre",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Javítási lépés:",
    "Repair info:" : "Javítási információ:",
    "Repair warning:" : "Javítási figyelmeztetés:",
    "Repair error:" : "Javítási hiba:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Használja a parancssoros frissítőt, mert az automatikusa frissítés ki van kapcsolva a config.php-ban.",
    "Turned on maintenance mode" : "Karbantartási mód bekapcsolva",
    "Turned off maintenance mode" : "Karbantartási mód kikapcsolva",
    "Maintenance mode is kept active" : "Karbantartási mód aktiválva maradt",
    "Updating database schema" : "Adatbázis séma frissítése",
    "Updated database" : "Adatbázis frissítve",
    "Update app \"%s\" from App Store" : "A(z) „%s” alkalmazás frissítése az alkalmazástárból",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Ellenőrzés, hogy a %s adatbázis sémája frissíthető-e (ez az adatbázis méretétől függően hosszabb ideig is eltarthat)",
    "Updated \"%1$s\" to %2$s" : "„%1$s” frissítve erre: %2$s",
    "Set log level to debug" : "Naplózási szint beállítása hibakeresésre",
    "Reset log level" : "Naplózási szint visszaállítása",
    "Starting code integrity check" : "Kódintegritási ellenőrzés indítása",
    "Finished code integrity check" : "Kódintegritási ellenőrzés befejezve",
    "%s (incompatible)" : "%s (nem kompatibilis)",
    "The following apps have been disabled: %s" : "A következő alkalmazások le lettek tiltva: %s",
    "Already up to date" : "Már naprakész",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "A webkiszolgáló nincs megfelelően beállítva a fájlok szinkronizálásához, mert a WebDAV interfész hibásnak tűnik.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Webkiszolgálója nincs megfelelően beállítva a(z) „{url}” feloldására. További információk a {linkstart}dokumentációban találhatók ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Webkiszolgálója nincs megfelelően beállítva a(z) „{url}” feloldására. Ez valószínűleg egy webkiszolgáló konfigurációhoz kapcsolódik, amelyet nem frissítettek, hogy ezt a mappát közvetlenül kézbesítse. Hasonlítsa össze a konfigurációt az Apache „.htaccess” fájljának átírt szabályaival, vagy az Nginx a {linkstart}dokumentációs oldalán ↗ {linkend} megadottak szerint. Nginx esetén jellemzően a „location ~” kezdetű sorokat kell frissíteni.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "A webkiszolgálója nincs megfelelően beállítva a .woff2 fájlok kiszolgálásához. Ezt jellemzőn a Nginx konfiguráció problémája okozza. A Nextcloud 15 esetén módosításokra van szükség a .woff2 fájlok miatt. Hasonlítsa össze az Nginx konfigurációját a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentációnkban ↗</a> javasolt konfigurációval.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Úgy tűnik a PHP nincs rendesen beállítva a rendszer környezeti változóinak lekéréséhez. A getenv(\"PATH\") teszt csak üres értéket ad vissza.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Ellenőrizze a {linkstart}telepítési dokumentációban ↗{linkend} a PHP konfigurációs megjegyzéseit, és a kiszolgáló PHP konfigurációját, különösen a php-fpm használatakor.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Csak olvasható beállítófájl engedélyezve. Ez meggátolja a beállítások módosítását a webes felületről. Továbbá, a fájlt kézzel kell írhatóvá tenni minden módosításhoz.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Még nem adta meg, vagy nem ellenőrizte az e-mail-kiszolgáló beállításait. Menjen a {mailSettingsStart}Alapvető beállításokhoz{mailSettingsEnd}, hogy beállítsa. Ezután használja az „E-mail küldése” gombot, hogy ellenőrizze a beállításokat.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Az adatbázis nem „READ COMMITTED” tranzakció izolációs szinttel fut. Ez problémákat okozhat több egyidejű esemény végrehajtásakor.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "A „fileinfo” PHP modul hiányzik. Erősen javasolt a modul engedélyezése a MIME-típusok lehető legjobb felismeréséhez.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "A tranzakciós fájlok zárolása le van tiltva, ez problémákhoz vezethet, ha versenyhelyzet lép fel. A problémák elkerülése érdekében engedélyezze a „filelocking.enabled” beállítást a config.php fájlban. További információkért lásd a {linkstart}dokumentációt ↗{linkend}.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Győződjön meg róla, hogy beállította arra az URL-re az „overwrite.cli.url” lehetőséget a config.php fájlban, amelyen a felhasználók elérik ezt a Nextcloudot. Javaslat: „{suggestedOverwriteCliURL}”. Különben problémák lehetnek a cronnal történő URL-előállítással. (Lehetséges, hogy a javasolt URL nem az, amellyel a felhasználók elsődlegesen elérik a Nextcloudot. Jobb, ha a biztonság kedvéért még egyszer ellenőrzi.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "A telepítéshez nincs megadva alapértelmezett telefonrégió. Erre a telefonszámok országkód nélküli hitelesítéséhez van szükség a profilbeállításokban. Ha országkód nélküli számokat szeretne engedélyezni, vegye fel a konfigurációs fájlba az „default_phone_region” szót a régió megfelelő {linkstart}ISO 3166-1 kódjával ↗{linkend}.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Az ütemezett feladatot nem lehetett parancssorból futtatni. A következő műszaki hiba lépett fel:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "A háttérfeladat végrehajtása {relativeTime} futott utoljára. Valami rossznak tűnik. {linkstart}Ellenőrizze a háttérfeladat beállításait ↗{linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Ez a Nextcloud nem támogatott közösségi kiadása. A példány mérete miatt a teljesítménye, megbízhatósága és skálázhatósága nem garantálható. A leküldéses értesítések korlátozottak, hogy ne terheljék túl az ingyenes szolgáltatásunkat. Tudjon meg többet a Nextcloud Enterprise előnyeiről a {linkstart}nextcloud.com/enterprise{linkend} oldalon.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Ennek a kiszolgálónak nincs működő internetkapcsolata: több végpont nem érhető el. Ez azt jelenti, hogy néhány funkció, mint például a külső tárolók csatolása, a frissítési értesítések, vagy a harmadik féltől származó alkalmazások telepítése nem fog működni. Lehet, hogy a fájlok távoli elérése és az e-mail értesítések sem működnek. Létesítsen internetkapcsolatot a kiszolgálón, ha minden funkciót használni szeretne.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nincs beállítva memória gyorsítótár. A teljesítmény növelése érdekében állítson be egy memcache-t, ha van ilyen. További információk a {linkstart}dokumentációban találhatók ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "A PHP nem talált megfelelő véletlenszerűségi forrást, amely biztonsági okokból erősen ellenjavallt. További információk a {linkstart}dokumentációban találhatók ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Ön jelenleg a következő verziójú PHP-t futtatja: {version}. Amint a disztribúciója támogatja, frissítse a PHP verzióját, hogy kihasználhassa a {linkstart}PHP Group által nyújtott teljesítménybeli és biztonsági frissítéseket ↗{linkend}.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "A Nextcloud 23 az utolsó olyan kiadás, amely támogatja a PHP 7.3-as verzióját. A Nextcloud 21 legalább PHP 7.4-et igényel.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "A fordított proxy fejléc konfigurációja helytelen, vagy egy megbízható proxyból érhető el a Nextcloud. Ha nem, akkor ez biztonsági probléma, és lehetővé teheti a támadók számára, hogy a Nextcloud számára látható  IP-címüket meghamisítsák. További információk a {linkstart}dokumentációban találhatók ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "A Memcached elosztott gyorsítótárként van konfigurálva, de rossz „memcache” PHP modul van telepítve. Az OC\\Memcache\\Memcached csak a „memcached” modult támogatja, a „memcache”-t nem. Lásd a {linkstart}memcached wiki-t mindkét modulról ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Néhány fájl elbukott az integritásellenőrzésen. További információk a probléma megoldásáról a {linkstart1}dokumentációban találhatók ↗{linkend}. ({linkstart2}Érvénytelen fájlok listája…{linkend} / {linkstart3}Újrakeresés…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "A PHP OPcache modul nem helyesen van beállítva. További információkért nézze meg a {linkstart}dokumentációt ↗{linkend}.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A „set_time_limit” PHP függvény nem érhető el. Emiatt egy szkript megszakadhat futás közben, a telepítés hibáját okozva. A függvény engedélyezése erősen javallott.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "A PHP-ból hiányzik a FreeType-támogatás. Ez a beállítási felület és a profilképek hibás megjelenítését okozhatja.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "A(z) „{indexName}” index hiányzik a(z) „{tableName}” táblában.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Az adatbázisból hiányzik néhány index. Mivel az indexek hozzáadása nagy táblák esetén sokáig tarthat, ezért nem lettek automatikusan létrehozva. Futtassa az „occ db:add-missing-indices” parancsot, hogy kézzel létrehozza a hiányzó indexeket, miközben a példány továbbra is fut. Amint az indexek létre lettek hozva, a lekérdezések gyorsabban fognak futni azokon a táblákon.",
    "Missing primary key on table \"{tableName}\"." : "Hiányzik az elsődleges kulcs a(z) „{tableName}” táblában.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Az adatbázisból hiányzik néhány elsődleges kulcs. Mivel az elsődleges kulcsok hozzáadása nagy táblák esetén sokáig tarthat, ezért nem lettek automatikusan létrehozva. Futtassa az „occ db:add-missing-primary-keys” parancsot, hogy kézzel létrehozza a hiányzó elsődleges kulcsokat, miközben a példány továbbra is fut.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "A nem kötelező oszlop „{columnName}” hiányzik a „{tableName}” táblában.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Az adatbázisból hiányzik néhány nem kötelező oszlop. Mivel az oszlopok hozzáadása sokáig tart a nagy tábláknál, ezért a nem kötelező oszlopok nem lettek automatikusan hozzáadva. A hiányzó oszlopokat az „occ db:add-missing-columns” paranccsal lehet kézileg hozzáadni a példány futása közben. Az oszlopok hozzáadása után bizonyos funkciók válaszideje és használhatósága javulni fog.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Ennél a példánynál hiányzik néhány javasolt PHP modul. A jobb teljesítmény és nagyobb kompatibilitás miatt ezek telepítése erősen javallott.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Az „imagick” PHP-modul nem engedélyezett, de a témázó alkalmazás igen. A webhelyikonok előállításához telepítenie és engedélyeznie kell ezt a modult.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "A „gmp” vagy a „bcmath” PHP modulok nem engedélyezettek. Ha WebAuthn jelszó nélküli hitelesítést használ, akkor szükség van ezekre a modulokra.",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Úgy tűnik, hogy 32 bites PHP verziót használ. A Nextcloud megfelelő futtatásához 64 bites szükséges. Frissítse 64 bitesre az operációs rendszerét és a PHP-ját. További részletekért olvassa el az {linkstart}erről szóló dokumentációs oldalt ↗{linkend}.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "A php-imagick modul ebben az esetben nem rendelkezik SVG támogatással. A jobb kompatibilitás érdekében ajánlott telepíteni.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Az adatbázis egyes oszlopaiból hiányzik a big int átalakítás. MIvel a nagy táblák oszloptípusainak megváltoztatása eltarthat egy ideig, azok nem lettek automatikusan megváltoztatva. Az „occ db: convert-filecache-bigint” futtatásával ezek a függőben lévő módosítások kézileg is alkalmazhatók. Ezt a műveletet offline állapotban kell végrehajtani. További részletekért olvassa el a {linkstart}erről szóló dokumentációs oldalt ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Jelenleg SQLite van háttéradatbázisként használva. Nagyobb telepítésekhez javasoljuk, hogy váltson más háttéradatbázisra. ",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Ezt különösen akkor javasoljuk, ha asztali klienst használ fájlszinkronizálásához.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Más adatbázisba történő áttéréshez használja a parancssori eszközt: „occ db: convert-type”, vagy tekintse meg a {linkstart}dokumentációt ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "A PHP memóriakorlátja az ajánlott 512 MB alatt van.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Néhány alkalmazáskönyvtár tulajdonosa különbözik a webkiszolgálóétól. Ez akkor fordul elő, ha az alkalmazás kézileg lett telepítve. Ellenőrizze az alábbi alkalmazáskönyvtárak jogosultságát:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "A MySQL adatbázis van használatban, de nem támogatja a 4 bájtos karaktereket. Hogy a 4 bájtos karakterek (például az emodzsikat) problémák nélkül kezelhetők legyenek, például a fájlnevekben vagy a megjegyzésekben, ajánlott engedélyezni a 4 bájtos támogatást a MySQL-ben. További részletekért olvassa el a {linkstart}erről szóló dokumentációs oldalt ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Ez a példány S3-alapú objektumtárat használ elsődleges tárolóként. A feltöltött fájlok ideiglenesen a kiszolgálón tároltak, így ajánlott hogy legalább 50GB szabad tárhely legyen a PHP ideiglenes könyvtárában. Ellenőrizze a naplókat az útvonal pontos részletei és az elérhető hely miatt. Hogy ezen javítson, módosítsa az ideiglenes könyvtárat a php.ini-ben, vagy szabadítson fel helyet azon az útvonalon.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "A példány ideiglenes könyvtára egy nem létező vagy egy nem írható könyvtárra mutat.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Biztonságos kapcsolaton keresztül éri el a példányát, azonban a példánya nem biztonságos URL-eket hoz létre. Ez nagy valószínűséggel azt jelenti, hogy egy fordított proxy mögött áll, és a konfigurációs változók felülírása nincs megfelelően beállítva. Olvassa el az {linkstart}erről szóló dokumentációs oldalt{linkend}.",
    "Error occurred while checking server setup" : "Hiba történt a kiszolgálóbeállítások ellenőrzésekor",
    "For more details see the {linkstart}documentation ↗{linkend}." : "További részletekért lásd a {linkstart}dokumentációt↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Az adatkönyvtárai és a fájljai valószínűleg elérhetőek az internetről. A .htaccess fájl nem működik. Erősen javasolt, hogy a webkiszolgálót úgy állítsa be, hogy az adatkönyvtár tartalma ne legyen közvetlenül elérhető, vagy helyezze át a könyvtárat a kiszolgálási területen kívülre.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "A(z) „{header}” HTTP-fejléc nem erre van állítva: „{expected}”. Ez egy lehetséges biztonsági és adatvédelmi kockázat, ezért javasolt, hogy módosítsa megfelelően a beállítást.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "A(z) „{header}” HTTP-fejléc nem erre van állítva: „{expected}”. Egyes szolgáltatások esetleg nem fognak megfelelően működni, ezért javasolt, hogy módosítsa megfelelően a beállítást.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "A(z) „{header}” HTTP-fejléc nem tartalmazza ezt: „{expected}”. Ez egy lehetséges biztonsági és adatvédelmi kockázat, ezért javasolt, hogy módosítsa megfelelően a beállítást.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "A „{header}” HTTP-fejléc értéke nem a következők egyiket: „{val1}”, „{val2}”, „{val3}”, „{val4}” vagy „{val5}”. Ez kiszivárogtathatja a hivatkozói információkat. Lásd a {linkstart}W3C ajánlást ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "A „Strict-Transport-Security” HTTP-fejléc nincs beállítva legalább „{seconds}” másodpercre. A fokozott biztonság érdekében ajánlott engedélyezni a HSTS-t a {linkstart}biztonsági tippek ↗{linkend} leírása szerint.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "A webhely elérése nem biztonságos HTTP-n keresztül. Javasoljuk, hogy úgy állítsa be a kiszolgálót, hogy követelje meg a HTTPS-t, amint azt a {linkstart}biztonsági tippek ↗{linkend} leírják.",
    "unknown text" : "ismeretlen szöveg",
    "Hello world!" : "Helló világ!",
    "sunny" : "napos",
    "Hello {name}, the weather is {weather}" : "Üdv {name}, {weather} időnk van",
    "Hello {name}" : "Üdv {name}!",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ezek a találatok<script>alert(1)</script></strong>",
    "new" : "új",
    "_download %n file_::_download %n files_" : ["%n fájl letöltése","%n fájl letöltése"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "A frissítés folyamatban van, az oldal elhagyása egyes környezetekben megszakíthatja a folyamatot.",
    "Update to {version}" : "Frissítés erre: {version}",
    "An error occurred." : "Hiba történt.",
    "Please reload the page." : "Frissítse az oldalt.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A frissítés sikertelen. Bővebb információért <a href=\"{url}\">keresse fel a problémáról szóló fórumbejegyzésünket</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A frissítés sikertelen. Jelezze a problémát a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud közösségnek</a>.",
    "Continue to {productName}" : "Tovább erre: {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A frissítés sikeres volt. %n másodperc múlva átirányítjuk a(z) {productName} címre.","A frissítés sikeres volt. %n másodperc múlva átirányítás a(z) {productName} címre."],
    "More apps" : "További alkalmazások",
    "Currently open" : "Jelenleg nyitva",
    "_{count} notification_::_{count} notifications_" : ["{count} értesítés","{count} értesítés"],
    "Log in" : "Bejelentkezés",
    "Logging in …" : "Bejelentkezés…",
    "Server side authentication failed!" : "A kiszolgálóoldali hitelesítés sikertelen.",
    "Please contact your administrator." : "Lépjen kapcsolatba a rendszergazdával.",
    "An internal error occurred." : "Belső hiba történt.",
    "Please try again or contact your administrator." : "Próbálja meg újra, vagy vegye fel a kapcsolatot a rendszergazdával.",
    "Password" : "Jelszó",
    "Wrong username or password." : "Hibás felhasználónév vagy jelszó.",
    "User disabled" : "Felhasználó letiltva",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Többszöri sikertelen bejelentkezési kísérletet észleltünk az IP-címéről. A legközelebbi kísérlete így 30 másodperccel késleltetve lesz.",
    "Username or email" : "Felhasználónév vagy e-mail-cím",
    "Your account is not setup for passwordless login." : "A fiókja nincs beállítva jelszómentes bejelentkezésre.",
    "Browser not supported" : "A böngésző nem támogatott",
    "Passwordless authentication is not supported in your browser." : "A jelszó nélküli hitelesítést nem támogatja a böngészője.",
    "Your connection is not secure" : "A kapcsolat nem biztonságos",
    "Passwordless authentication is only available over a secure connection." : "A jelszó nélküli hitelesítés csak biztonságos kapcsolaton keresztül érhető el.",
    "Reset password" : "Jelszó-visszaállítás",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Egy jelszó visszaállítási e-mail lett küldve a fiók e-mail-címére. Ha nem kapta meg, akkor ellenőrizze a levélszemét mappát, vagy kérje a helyi rendszergazda segítségét.",
    "If it is not there ask your local administrator." : "Ha nincs ott, akkor kérdezze a helyi rendszergazdát.",
    "Couldn't send reset email. Please contact your administrator." : "Nem küldhető visszaállítási e-mail. Lépjen kapcsolatba a rendszergazdával.",
    "Password cannot be changed. Please contact your administrator." : "A jelszó nem módosítható. Lépjen kapcsolatba a rendszergazdával.",
    "Back to login" : "Vissza a bejelentkezéshez",
    "New password" : "Új jelszó",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "A fájljai titkosítva vannak. A jelszó visszaállítása után sehogy sem fogja tudja visszaszerezni azokat. Ha nem tudja mi a teendő, akkor beszéljen a helyi rendszergazdával. Biztos, hogy folytatja?",
    "I know what I'm doing" : "Tudom mit csinálok.",
    "Resetting password" : "Jelszó visszaállítása",
    "Recommended apps" : "Ajánlott alkalmazások",
    "Loading apps …" : "Alkalmazások betöltése…",
    "Could not fetch list of apps from the App Store." : "Az alkalmazások listája nem kérhető le az alkalmazástárból.",
    "Installing apps …" : "Alkalmazások telepítése…",
    "App download or installation failed" : "Alkalmazás letöltése vagy telepítése sikertelen",
    "Cannot install this app because it is not compatible" : "Az alkalmazás nem telepíthető, mert nem kompatibilis",
    "Cannot install this app" : "Az alkalmazás nem telepíthető",
    "Skip" : "Kihagyás",
    "Install recommended apps" : "Javasolt alkalmazások telepítése",
    "Schedule work & meetings, synced with all your devices." : "Ütemezett munkáját és találkozóit, szinkronizálva az összes eszközén.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Tartsa egy helyen kollégáit és barátait, anélkül hogy kiszivárogtatná a személyes adataikat.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Egyszerű e-mail alkalmazás, amely szépen integrálódik a Fájlok, Névjegyek és Naptár alkalmazásba.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Csevegés, videóhívások, képernyőmegosztás, online megbeszélések és webes konferencia – a böngészőjében és mobilalkalmazásokkal.",
    "Collaboratively edit office documents." : "Szerkesszen közösen irodai dokumentumokat.",
    "Local document editing back-end used by the Collabora Online app." : "Helyi dokumentumszerkesztési háttérprogram, amit a Collabora Online alkalmazás használ.",
    "Forgot password?" : "Elfelejtett jelszó?",
    "Log in with a device" : "Bejelentkezés eszközzel",
    "Back" : "Vissza",
    "Login form is disabled." : "A bejelentkezési űrlap letiltva.",
    "Edit Profile" : "Profil szerkesztése",
    "The headline and about sections will show up here" : "A fejléc és a névjegy szakaszok itt fognak megjelenni",
    "You have not added any info yet" : "Még nem adott meg semmilyen információt",
    "{user} has not added any info yet" : "{user} még nem adott meg semmilyen információt",
    "Error opening the user status modal, try hard refreshing the page" : "Hiba a felhasználói állapot párbeszédablak megnyitásakor, próbálja meg az oldal kényszerített újratöltését",
    "Search starts once you start typing" : "A keresés elindul, ha elkezd gépelni",
    "Reset search" : "Keresés visszaállítása",
    "Start search" : "Keresés indítása",
    "Search for {name} only" : "Keresés csak a(z) {name} kifejezésre",
    "No results for {query}" : "Nincs találat a következőre: {query}",
    "Press enter to start searching" : "A keresés indításához nyomjon Entert",
    "Start typing to search" : "Kezdjen el gépelni a kereséshez",
    "Loading more results …" : "További találatok betöltése…",
    "Load more results" : "További találatok betöltése",
    "Search" : "Keresés",
    "An error occurred while searching for {type}" : "Hiba történt a(z) {type} keresése sorá",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["A kereséshez írjon be a legalább {minSearchLength} karaktert","A kereséshez írjon be a legalább {minSearchLength} karaktert"],
    "Search {types} …" : "{types} keresése…",
    "Settings" : "Beállítások",
    "Could not load your contacts" : "Nem lehet betölteni a névjegyeit",
    "Search contacts …" : "Névjegyek keresése…",
    "No contacts found" : "Nem találhatók névjegyek",
    "Show all contacts …" : "Minden névjegy megjelenítése…",
    "Install the Contacts app" : "A Névjegyek alkalmazás telepítése",
    "Loading your contacts …" : "Névjegyek betöltése…",
    "Looking for {term} …" : "{term} keresése…",
    "No" : "Nem",
    "Yes" : "Igen",
    "No files in here" : "Itt nincsenek fájlok",
    "New folder" : "Új mappa",
    "No more subfolders in here" : "Itt nincsenek almappák",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "\"{name}\" is an invalid file name." : "A(z) „{name}” fájlnév érvénytelen.",
    "File name cannot be empty." : "A fájlnév nem lehet üres.",
    "\"/\" is not allowed inside a file name." : "„/” nem szerepelhet fájlnévben.",
    "\"{name}\" is not an allowed filetype" : "A(z) „{name}” nem engedélyezett fájltípus",
    "{newName} already exists" : "{newName} már létezik",
    "Choose" : "Válasszon",
    "Copy" : "Másolás",
    "Move" : "Áthelyezés",
    "Error loading file picker template: {error}" : "Hiba a fájlválasztó sablon betöltésekor: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Hiba az üzenetsablon betöltésekor: {error}",
    "read-only" : "csak olvasható",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} fájl ütközik","{count} fájl ütközik"],
    "One file conflict" : "Egy fájl ütközik",
    "New Files" : "Új fájlok",
    "Already existing files" : "Meglévő fájlok",
    "Which files do you want to keep?" : "Mely fájlokat akarja megtartani?",
    "If you select both versions, the copied file will have a number added to its name." : "Ha mindkét verziót kiválasztja, a másolt fájlok neve sorszámozva lesz.",
    "Cancel" : "Mégse",
    "Continue" : "Folytatás",
    "(all selected)" : "(összes kiválasztva)",
    "({count} selected)" : "({count} kiválasztva)",
    "Error loading file exists template" : "Hiba a „fájl már létezik” sablon betöltésekor",
    "Show list view" : "Listanézet megjelenítése",
    "Show grid view" : "Rácsnézet megjelenítése",
    "Pending" : "Folyamatban",
    "Copy to {folder}" : "Másolás ide: {folder}",
    "Move to {folder}" : "Áthelyezés ide: {folder}",
    "Saving …" : "Mentés ...",
    "Authentication required" : "Hitelesítés szükséges",
    "This action requires you to confirm your password" : "A művelethez meg kell erősítenie a jelszavát",
    "Confirm" : "Megerősítés",
    "Failed to authenticate, try again" : "A hitelesítés sikertelen, próbálja újra",
    "seconds ago" : "pár másodperce",
    "Connection to server lost" : "A kapcsolat megszakadt a kiszolgálóval",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probléma az oldal betöltésekor, újratöltés %n másodperc múlva","Probléma az oldal betöltésekor, újratöltés %n másodperc múlva"],
    "Add to a project" : "Hozzáadás egy projekthez",
    "Show details" : "Részletek megjelenítése",
    "Hide details" : "Részletek elrejtése",
    "Rename project" : "Projekt átnevezése",
    "Failed to rename the project" : "A projekt átnevezése sikertelen",
    "Failed to create a project" : "A projekt létrehozása sikertelen",
    "Failed to add the item to the project" : "Az elem hozzáadása a projekthez sikertelen",
    "Connect items to a project to make them easier to find" : "Kössön hozzá elemeket a projekthez, hogy könnyebben megtalálhatóak legyenek",
    "Type to search for existing projects" : "Gépeljen a meglévő projektet kereséséhez",
    "New in" : "Új itt",
    "View changelog" : "Változásnapló megtekintése",
    "Very weak password" : "Nagyon gyenge jelszó",
    "Weak password" : "Gyenge jelszó",
    "So-so password" : "Nem túl jó jelszó",
    "Good password" : "Megfelelő jelszó",
    "Strong password" : "Erős jelszó",
    "No action available" : "Nincs elérhető művelet",
    "Error fetching contact actions" : "Hiba a kapcsolati műveletek lekérésekor",
    "Non-existing tag #{tag}" : "Nem létező címke #{tag}",
    "restricted" : "korlátozott",
    "invisible" : "láthatatlan",
    "Delete" : "Törlés",
    "Rename" : "Átnevezés",
    "Collaborative tags" : "Együttműködési címkék",
    "No tags found" : "Nem találhatók címkék",
    "Personal" : "Személyes",
    "Users" : "Felhasználók",
    "Apps" : "Alkalmazások",
    "Admin" : "Rendszergazda",
    "Help" : "Súgó",
    "Access forbidden" : "A hozzáférés nem engedélyezett",
    "Profile not found" : "Nem található profil",
    "The profile does not exist." : "A profil nem létezik.",
    "Back to %s" : "Vissza ide %s",
    "File not found" : "Fájl nem található",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "A dokumentum nem található a szerveren. Valószínűleg a megosztás törölve lett vagy lejárt.",
    "Too many requests" : "Túl sok kérés",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Túl sok kérés érkezett a hálózatától. Próbálja újra később, vagy ha ez egy hiba, akkor forduljon a rendszergazdához.",
    "Error" : "Hiba",
    "Previous" : "Előző",
    "Internal Server Error" : "Belső kiszolgálóhiba",
    "The server was unable to complete your request." : "A szerver nem tudta végrehajtani a kérésed.",
    "If this happens again, please send the technical details below to the server administrator." : "Ha ez még egyszer előfordul küldd el az alábbi technikai részleteket a rendszergazdának.",
    "More details can be found in the server log." : "További részletek találhatók a kiszolgáló naplójában.",
    "Technical details" : "Technikai adatok",
    "Remote Address: %s" : "Távoli cím: %s",
    "Request ID: %s" : "Kérésazonosító: %s",
    "Type: %s" : "Típus: %s",
    "Code: %s" : "Kód: %s",
    "Message: %s" : "Üzenet: %s",
    "File: %s" : "Fájl: %s",
    "Line: %s" : "Sor: %s",
    "Trace" : "Nyomkövetés",
    "Security warning" : "Biztonsági figyelmeztetés",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Az adatkönyvtár és a benne levő fájlok valószínűleg közvetlenül is elérhetők az internetről, mert a .htaccess fájl nem érvényesül.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "További információkért a szervered helyes beállításához nézd meg a <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentációt</a>.",
    "Create an <strong>admin account</strong>" : "<strong>Rendszergazdai fiók</strong> létrehozása",
    "Username" : "Felhasználónév",
    "Show password" : "Jelszó megjelenítése",
    "Toggle password visibility" : "Jelszó láthatósága be/ki",
    "Storage & database" : "Tárhely és adatbázis",
    "Data folder" : "Adat mappa",
    "Configure the database" : "Adatbázis konfigurálása",
    "Only %s is available." : "Csak %s érhető el.",
    "Install and activate additional PHP modules to choose other database types." : "Telepítse és aktiválja a bővített PHP modulokat, hogy tudjon más adatbázis típust is kiválasztani.",
    "For more details check out the documentation." : "További részletekért nézze meg a dokumentációt.",
    "Database user" : "Adatbázis felhasználónév",
    "Database password" : "Adatbázis jelszó",
    "Database name" : "Az adatbázis neve",
    "Database tablespace" : "Az adatbázis táblázattér (tablespace)",
    "Database host" : "Adatbázis-kiszolgáló",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Adja meg a port számát a kiszolgáló neve után (például localhost:5432).",
    "Performance warning" : "Teljesítménybeli figyelmeztetés",
    "You chose SQLite as database." : "SQLite adatbázist választott.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Az SQLite-ot csak minimális és fejlesztési célú példányok esetén szabad használni. Éles működés esetén más adatbázis-kezelőt ajánlunk.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ha klienseket használt a fájlszinkronizáláshoz, akkor az SQLite használata erősen ellenjavallt.",
    "Install" : "Telepítés",
    "Installing …" : "Telepítés…",
    "Need help?" : "Segítségre van szüksége?",
    "See the documentation" : "Nézze meg a dokumentációt",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Úgy néz ki, hogy a Nextcloud újratelepítésére készül. Viszont a CAN_INSTALL fájl hiányzik a config könyvtárból. A folytatáshoz hozza létre a CAN_INSTALL fájlt a konfigurációs mappában.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "A CAN_INSTALL nem távolítható el a konfigurációs mappából. Törölje a fájlt kézileg.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Az alkalmazás megfelelő működéséhez JavaScript szükséges. {linkstart}Engedélyezze a JavaScriptet{linkend}, és frissítse a lapot.",
    "Skip to main content" : "Ugrás a fő tartalomhoz",
    "Skip to navigation of app" : "Ugrás az alkalmazás navigációjához",
    "Get your own free account" : "Szerezzen saját ingyenes fiókot",
    "%s's homepage" : "%s honlapja",
    "Contacts" : "Névjegyek",
    "Contacts menu" : "Névjegyek menü",
    "Open settings menu" : "Beállítások megnyitása",
    "Confirm your password" : "Erősítse meg a jelszavát:",
    "Connect to your account" : "Kapcsolódás a fiókjához",
    "Please log in before granting %1$s access to your %2$s account." : "Lépjen be mielőtthozzáférést biztosít a(z) %1$s kliensnek a(z) %2$s fiókjához.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ha nem új eszközt vagy alkalmazást próbál beállítani, akkor valaki megpróbálja becsapni, hogy hozzáférést biztosítson számára az adatokhoz. Ebben az esetben ne folytassa, hanem lépjen kapcsolatba a rendszergazdával.",
    "App token" : "Alkalmazástoken",
    "Grant access" : "Hozzáférés megadása",
    "Alternative log in using app token" : "Alternatív bejelentkezés alkalmazástoken segítségével",
    "Account access" : "Fiókhozzáférés",
    "Currently logged in as %1$s (%2$s)." : "Jelenleg bejelentkezve: %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Hozzáférést készül biztosítani %1$s számára ehhez a fiókjához: %2$s.",
    "Account connected" : "Fiók csatlakoztatva",
    "Your client should now be connected!" : "A kliens most már kapcsolódik.",
    "You can close this window." : "Bezárhatja ezt az ablakot.",
    "This share is password-protected" : "Ez a megosztás jelszóval védett",
    "The password is wrong or expired. Please try again or request a new one." : "A jelszó hibás vagy lejárt. Próbálja újra, vagy kérjen újat.",
    "Please type in your email address to request a temporary password" : "Írja be az e-mail-címét, hogy ideiglenes jelszót kérjen",
    "Email address" : "E-mail-cím",
    "Password sent!" : "Jelszó elküldve.",
    "You are not authorized to request a password for this share" : "Nincs jogosultsága, hogy jelszót kérjen ehhez a megosztáshoz",
    "Go to %s" : "Ugrás ide: %s",
    "Two-factor authentication" : "Kétfaktoros hitelesítés",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "A fokozott biztonság engedélyezett a fiókja számára. Válasszon egy második faktort a hitelesítéshez.",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nem lehet betölteni legalább egy engedélyezett kétfaktoros hitelesítési módot. Lépjen kapcsolatba a rendszergazdával.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "A kétfaktoros hitelesítés kötelező, de még nem lett beállítva a fiókjához. Segítségért lépjen kapcsolatba a rendszergazdával.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "A kétfaktoros hitelesítés be van tartatva, de nincs beállítva a fiókján. Folytassa a kétfaktoros hitelesítés beállításával.",
    "Set up two-factor authentication" : "Kétfaktoros hitelesítés beállítása",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "A kétfaktoros hitelesítés be van tartatva, de nincs beállítva a fiókján. Használja a biztonsági kódjai egyikét a bejelentkezéshez, vagy ha segítségre van szüksége, akkor lépjen kapcsolatba a rendszergazdával.",
    "Use backup code" : "Biztonsági kód használata",
    "Cancel login" : "Bejelentkezés megszakítása",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "A fokozott biztonság be van tartatva a fiókjánál. Válassza ki a beállítandó szolgáltatót:",
    "Error while validating your second factor" : "Hiba történt a második faktor évényesítésekor",
    "Access through untrusted domain" : "Nem megbízható tartományon keresztüli hozzáférés",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Lépjen kapcsolatba a rendszergazdával. Ha Ön az, akkor szerkessze a „trusted_domains” beállítást a config/config.php-ban, a config.sample.php-hoz hasonlóan.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ennek a beállításához további információkat talál a %1$sdokumentációban%2$s.",
    "App update required" : "Alkalmazásfrissítés szükséges",
    "%1$s will be updated to version %2$s" : "A(z) %1$s frissítve lesz erre a verzióra: %2$s",
    "The following apps will be updated:" : "A következő alkalmazások lesznek frissítve:",
    "These incompatible apps will be disabled:" : "A következő nem kompatibilis alkalmazások le lesznek tiltva:",
    "The theme %s has been disabled." : "A(z) %s téma letiltásra került.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Gondoskodjon róla, hogy elmentse az adatbázist, a konfigurációs mappa és az adatmappa tartalmát, mielőtt folytatja.",
    "Start update" : "A frissítés megkezdése",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "A nagy méretű telepítések által okozott időtúllépések elkerülése érdekében, inkább futtassa a következő parancsot a telepítési alkönyvtárban:",
    "Detailed logs" : "Részletes naplók",
    "Update needed" : "Frissítés szükséges",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Használja a parancssori frissítőt, mert 50 felhasználósnál nagyobb példánya van.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Segítségért tekintse meg a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentációt</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tudomásul veszem, hogy a webes frissítési felület használata közben fellépő időtúllépés adatvesztéssel járhat. Van biztonsági mentésem, hiba esetén tudom, hogyan állítsam vissza az adatokat.",
    "Upgrade via web on my own risk" : "Frissítés weben keresztül, saját felelősségre",
    "Maintenance mode" : "Karbantartási üzemmód",
    "This %s instance is currently in maintenance mode, which may take a while." : "Ez a %s példány éppen karbantartási üzemmódban van, amely eltarthat egy darabig.",
    "This page will refresh itself when the instance is available again." : "Ez az oldal frissíteni fogja magát, amint a példány ismét elérhető lesz.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Ha ez az üzenet mindig vagy váratlanul megjelenik, akkor keresse fel a rendszergazdáját!",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Tábla ellenőrzése: %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Ennek a kiszolgálónak nincs működő internetkapcsolata: több végpont nem érhető el. Ez azt jelenti, hogy néhány funkció, mint például a külső tárolók csatolása, a frissítési értesítések, vagy a harmadik féltől származó alkalmazások telepítése nem fog működni. Lehet, hogy a fájlok távoli elérése és az e-mail értesítések sem működnek. Létesítsen internetkapcsolatot a kiszolgálón, ha minden funkciót használni szeretne.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "A Nextcloud 20 az utolsó olyan kiadás, amely támogatja a PHP 7.2-es verziót. A Nextcloud 21 legalább PHP 7.3-at igényel.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "A PHP OPcache modul nincs betöltve. {linkstart}A jobb teljesítmény érdekében javasoljuk, hogy ↗{link} töltse be a PHP telepítésébe.",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "A PHP OPcache modul nincs megfelelően konfigurálva. {linkstart}A jobb teljesítmény érdekében ↗{linkend} ajánlott a következő beállításokat használni a <code>php.ini</code> fájlban:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Az adatbázis egyes oszlopaiból hiányzik a big int átalakítás. MIvel a nagy táblák oszloptípusainak megváltoztatása eltarthat egy ideig, azok nem lettek automatikusan megváltoztatva. Az „occ db: convert-filecache-bigint” futtatásával ezek a függőben lévő módosítások kézileg is alkalmazhatók. Ezt a műveletet offline állapotban kell végrehajtani. További részletekért olvassa el a {linkstart}erről szóló dokumentációs oldalt ↗{linkend}.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Más adatbázisba történő áttéréshez használja a parancssori eszközt: „occ db: convert-type”, vagy tekintse meg a {linkstart}dokumentációt ↗{linkend}.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Az adatkönyvtárai és a fájljai valószínűleg elérhetőek az internetről. A .htaccess fájl nem működik. Erősen javasolt, hogy a webkiszolgálót úgy állítsa be, hogy az adatkönyvtár tartalma ne legyen közvetlenül elérhető, vagy helyezze át a könyvtárat a kiszolgálási területen kívülre.",
    "More" : "Továbbiak",
    "More apps menu" : "További alkalmazások menü",
    "Settings menu" : "Beállítások menü",
    "The password is wrong. Try again." : "A megadott jelszó hibás. Próbálja újra.",
    "Setup two-factor authentication" : "Kétfaktoros hitelesítés beállítása",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "A Nextcloud e közösségi kiadása nem támogatott, és az azonnal értesítések nem érhetők el.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Ez a Nextcloud nem támogatott közösségi kiadása. A példány mérete miatt a teljesítménye, megbízhatósága és skálázhatósága nem garantálható. A leküldéses értesítések letiltásra kerültek, hogy ne terheljék túl az ingyenes szolgáltatásunkat. Tudjon meg többet a Nextcloud Enterprise előnyeiről a nextcloud.com/enterprise oldalon.",
    "You haven't added any info yet" : "Még nem adott hozzá információkat",
    "{user} hasn't added any info yet" : "{user} még nem adott hozzá információkat"
},
"nplurals=2; plural=(n != 1);");
